# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/community/member_user.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/community/member_user.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.community import email_type_pb2 as eolymp_dot_community_dot_email__type__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/community/member_user.proto\x12\x10\x65olymp.community\x1a!eolymp/community/email_type.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf0\x04\n\x04User\x12\x0e\n\x06issuer\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\x10\n\x08nickname\x18\n \x01(\t\x12\x1f\n\x17nickname_change_timeout\x18\x0b \x01(\r\x12-\n\x07\x61liases\x18\r \x03(\x0b\x32\x1c.eolymp.community.User.Alias\x12\r\n\x05\x65mail\x18\x14 \x01(\t\x12\x16\n\x0e\x65mail_verified\x18\x15 \x01(\x08\x12\x18\n\x10\x65mail_restricted\x18\x0c \x01(\x08\x12\x38\n\x13\x65mail_subscriptions\x18\x16 \x03(\x0e\x32\x1b.eolymp.community.EmailType\x12\x10\n\x08password\x18\x1e \x01(\t\x12\x14\n\x0cpassword_age\x18\x1f \x01(\r\x12\x0c\n\x04name\x18( \x01(\t\x12\x0f\n\x07picture\x18\x32 \x01(\t\x12,\n\x08\x62irthday\x18< \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x63ountry\x18\x46 \x01(\t\x12\x0c\n\x04\x63ity\x18I \x01(\t\x12\x0f\n\x07team_id\x18\x64 \x01(\t\x12\x38\n\x0bpreferences\x18\xa0\x06 \x01(\x0b\x32\".eolymp.community.User.Preferences\x1a@\n\x0bPreferences\x12\x0e\n\x06locale\x18\x01 \x01(\t\x12\x10\n\x08timezone\x18\x02 \x01(\t\x12\x0f\n\x07runtime\x18\n \x01(\t\x1aI\n\x05\x41lias\x12\x10\n\x08nickname\x18\x01 \x01(\t\x12.\n\nchanged_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.member_user_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _globals['_USER']._serialized_start=125
  _globals['_USER']._serialized_end=749
  _globals['_USER_PREFERENCES']._serialized_start=610
  _globals['_USER_PREFERENCES']._serialized_end=674
  _globals['_USER_ALIAS']._serialized_start=676
  _globals['_USER_ALIAS']._serialized_end=749
# @@protoc_insertion_point(module_scope)
