# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/content/translation_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/content/translation_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import namespace_pb2 as eolymp_dot_annotations_dot_namespace__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(eolymp/content/translation_service.proto\x12\x0e\x65olymp.content\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/namespace.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x18\x65olymp/ecm/content.proto\"=\n\x15TranslateContentInput\x12$\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x13.eolymp.ecm.Content\"B\n\x16TranslateContentOutput\x12(\n\x0btranslation\x18\x01 \x01(\x0b\x32\x13.eolymp.ecm.Content2\xbe\x01\n\x10TranslateService\x12\x8c\x01\n\x10TranslateContent\x12%.eolymp.content.TranslateContentInput\x1a&.eolymp.content.TranslateContentOutput\")\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x14\"\x12/content:translate\x1a\x1b\x82\xf0\xf0\xe4\x01\x15\x65olymp.universe.SpaceB1Z/github.com/eolymp/go-sdk/eolymp/content;contentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.content.translation_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/content;content'
  _globals['_TRANSLATESERVICE']._loaded_options = None
  _globals['_TRANSLATESERVICE']._serialized_options = b'\202\360\360\344\001\025eolymp.universe.Space'
  _globals['_TRANSLATESERVICE'].methods_by_name['TranslateContent']._loaded_options = None
  _globals['_TRANSLATESERVICE'].methods_by_name['TranslateContent']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\024\"\022/content:translate'
  _globals['_TRANSLATECONTENTINPUT']._serialized_start=189
  _globals['_TRANSLATECONTENTINPUT']._serialized_end=250
  _globals['_TRANSLATECONTENTOUTPUT']._serialized_start=252
  _globals['_TRANSLATECONTENTOUTPUT']._serialized_end=318
  _globals['_TRANSLATESERVICE']._serialized_start=321
  _globals['_TRANSLATESERVICE']._serialized_end=511
# @@protoc_insertion_point(module_scope)
