# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/content/content_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/content/content_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import namespace_pb2 as eolymp_dot_annotations_dot_namespace__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.content import content_fragment_pb2 as eolymp_dot_content_dot_content__fragment__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/content/content_service.proto\x12\x0e\x65olymp.content\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/namespace.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a%eolymp/content/content_fragment.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"x\n\x14\x46ragmentChangedEvent\x12\r\n\x05scope\x18\n \x01(\t\x12(\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x18.eolymp.content.Fragment\x12\'\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x18.eolymp.content.Fragment\"\xa1\x01\n\x1f\x46ragmentTranslationChangedEvent\x12\x13\n\x0b\x66ragment_id\x18\n \x01(\t\x12\x34\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32$.eolymp.content.Fragment.Translation\x12\x33\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32$.eolymp.content.Fragment.Translation\"b\n\x15\x44\x65scribeFragmentInput\x12\x13\n\x0b\x66ragment_id\x18\x01 \x01(\t\x12\x34\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32$.eolymp.content.Fragment.Extra.Field\"D\n\x16\x44\x65scribeFragmentOutput\x12*\n\x08\x66ragment\x18\x01 \x01(\x0b\x32\x18.eolymp.content.Fragment\"\xa2\x04\n\x12ListFragmentsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.content.ListFragmentsInput.Filter\x12\x35\n\x04sort\x18\x32 \x01(\x0e\x32\'.eolymp.content.ListFragmentsInput.Sort\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12\x0f\n\x06locale\x18\xe2\x08 \x01(\t\x12\x34\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32$.eolymp.content.Fragment.Extra.Field\x1a\xd8\x01\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04path\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x30\n\x06locale\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12/\n\x05label\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"-\n\x04Sort\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x08\n\x04PATH\x10\x01\x12\x0e\n\nCREATED_AT\x10\x02\"M\n\x13ListFragmentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.content.Fragment\"A\n\x13\x43reateFragmentInput\x12*\n\x08\x66ragment\x18\x01 \x01(\x0b\x32\x18.eolymp.content.Fragment\"+\n\x14\x43reateFragmentOutput\x12\x13\n\x0b\x66ragment_id\x18\x01 \x01(\t\"\x8b\x01\n\x13UpdateFragmentInput\x12\x33\n\x05patch\x18\x03 \x03(\x0e\x32$.eolymp.content.Fragment.Patch.Field\x12\x13\n\x0b\x66ragment_id\x18\x01 \x01(\t\x12*\n\x08\x66ragment\x18\x02 \x01(\x0b\x32\x18.eolymp.content.Fragment\"\x16\n\x14UpdateFragmentOutput\"*\n\x13\x44\x65leteFragmentInput\x12\x13\n\x0b\x66ragment_id\x18\x01 \x01(\t\"\x16\n\x14\x44\x65leteFragmentOutput\"\x80\x01\n\x16TranslateFragmentInput\x12\x13\n\x0b\x66ragment_id\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0e\n\x06target\x18\x03 \x03(\t\x12\x18\n\x10target_automatic\x18\x04 \x01(\x08\x12\x17\n\x0foverride_manual\x18\x05 \x01(\x08\")\n\x17TranslateFragmentOutput\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\x85\x01\n DescribeFragmentTranslationInput\x12\x13\n\x0b\x66ragment_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\x12\x34\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32$.eolymp.content.Fragment.Extra.Field\"^\n!DescribeFragmentTranslationOutput\x12\x39\n\x0btranslation\x18\x01 \x01(\x0b\x32$.eolymp.content.Fragment.Translation\"\xc6\x02\n\x1dListFragmentTranslationsInput\x12\x13\n\x0b\x66ragment_id\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x45\n\x07\x66ilters\x18( \x01(\x0b\x32\x34.eolymp.content.ListFragmentTranslationsInput.Filter\x12\x34\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32$.eolymp.content.Fragment.Extra.Field\x1au\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06locale\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"d\n\x1eListFragmentTranslationsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x33\n\x05items\x18\x02 \x03(\x0b\x32$.eolymp.content.Fragment.Translation\"p\n\x1e\x43reateFragmentTranslationInput\x12\x13\n\x0b\x66ragment_id\x18\x01 \x01(\t\x12\x39\n\x0btranslation\x18\x02 \x01(\x0b\x32$.eolymp.content.Fragment.Translation\"9\n\x1f\x43reateFragmentTranslationOutput\x12\x16\n\x0etranslation_id\x18\x01 \x01(\t\"\x88\x01\n\x1eUpdateFragmentTranslationInput\x12\x13\n\x0b\x66ragment_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\x12\x39\n\x0btranslation\x18\x03 \x01(\x0b\x32$.eolymp.content.Fragment.Translation\"!\n\x1fUpdateFragmentTranslationOutput\"M\n\x1e\x44\x65leteFragmentTranslationInput\x12\x13\n\x0b\x66ragment_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\"!\n\x1f\x44\x65leteFragmentTranslationOutput\"g\n\x11\x44\x65scribePathInput\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x02 \x01(\t\x12\x34\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32$.eolymp.content.Fragment.Extra.Field\"@\n\x12\x44\x65scribePathOutput\x12*\n\x08\x66ragment\x18\x01 \x01(\x0b\x32\x18.eolymp.content.Fragment\"f\n\x10ListParentsInput\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x02 \x01(\t\x12\x34\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32$.eolymp.content.Fragment.Extra.Field\"K\n\x11ListParentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.content.Fragment2\x9a\x17\n\x0e\x43ontentService\x12\xbb\x01\n\x10\x44\x65scribeFragment\x12%.eolymp.content.DescribeFragmentInput\x1a&.eolymp.content.DescribeFragmentOutput\"X\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xe3\n\x1c\x8a\xe3\n\x18typewriter:fragment:read\x82\xd3\xe4\x93\x02\"\x12 /content/fragments/{fragment_id}\x12\xa3\x01\n\rListFragments\x12\".eolymp.content.ListFragmentsInput\x1a#.eolymp.content.ListFragmentsOutput\"I\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x1c\x8a\xe3\n\x18typewriter:fragment:read\x82\xd3\xe4\x93\x02\x14\x12\x12/content/fragments\x12\xa7\x01\n\x0e\x43reateFragment\x12#.eolymp.content.CreateFragmentInput\x1a$.eolymp.content.CreateFragmentOutput\"J\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\x82\xd3\xe4\x93\x02\x14\"\x12/content/fragments\x12\xb5\x01\n\x0eUpdateFragment\x12#.eolymp.content.UpdateFragmentInput\x1a$.eolymp.content.UpdateFragmentOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\x82\xd3\xe4\x93\x02\"\x1a /content/fragments/{fragment_id}\x12\xb5\x01\n\x0e\x44\x65leteFragment\x12#.eolymp.content.DeleteFragmentInput\x1a$.eolymp.content.DeleteFragmentOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\x82\xd3\xe4\x93\x02\"* /content/fragments/{fragment_id}\x12\xc8\x01\n\x11TranslateFragment\x12&.eolymp.content.TranslateFragmentInput\x1a\'.eolymp.content.TranslateFragmentOutput\"b\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\x82\xd3\xe4\x93\x02,\"*/content/fragments/{fragment_id}/translate\x12\xb9\x02\n\x1b\x44\x65scribeFragmentTranslation\x12\x30.eolymp.content.DescribeFragmentTranslationInput\x1a\x31.eolymp.content.DescribeFragmentTranslationOutput\"\xb4\x01\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xe3\n\x1c\x8a\xe3\n\x18typewriter:fragment:read\x82\xd3\xe4\x93\x02~\x12>/content/fragments/{fragment_id}/translations/{translation_id}Z<\x12:/content/fragments/{fragment_id}/variants/{translation_id}\x12\x8d\x02\n\x18ListFragmentTranslations\x12-.eolymp.content.ListFragmentTranslationsInput\x1a..eolymp.content.ListFragmentTranslationsOutput\"\x91\x01\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x1c\x8a\xe3\n\x18typewriter:fragment:read\x82\xd3\xe4\x93\x02\\\x12-/content/fragments/{fragment_id}/translationsZ+\x12)/content/fragments/{fragment_id}/variants\x12\x91\x02\n\x19\x43reateFragmentTranslation\x12..eolymp.content.CreateFragmentTranslationInput\x1a/.eolymp.content.CreateFragmentTranslationOutput\"\x92\x01\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\x82\xd3\xe4\x93\x02\\\"-/content/fragments/{fragment_id}/translationsZ+\")/content/fragments/{fragment_id}/variants\x12\xb3\x02\n\x19UpdateFragmentTranslation\x12..eolymp.content.UpdateFragmentTranslationInput\x1a/.eolymp.content.UpdateFragmentTranslationOutput\"\xb4\x01\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\x82\xd3\xe4\x93\x02~\x1a>/content/fragments/{fragment_id}/translations/{translation_id}Z<\x1a:/content/fragments/{fragment_id}/variants/{translation_id}\x12\xb3\x02\n\x19\x44\x65leteFragmentTranslation\x12..eolymp.content.DeleteFragmentTranslationInput\x1a/.eolymp.content.DeleteFragmentTranslationOutput\"\xb4\x01\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\x82\xd3\xe4\x93\x02~*>/content/fragments/{fragment_id}/translations/{translation_id}Z<*:/content/fragments/{fragment_id}/variants/{translation_id}\x12\x9c\x01\n\x0c\x44\x65scribePath\x12!.eolymp.content.DescribePathInput\x1a\".eolymp.content.DescribePathOutput\"E\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xe3\n\x1c\x8a\xe3\n\x18typewriter:fragment:read\x82\xd3\xe4\x93\x02\x0f\x12\r/content/path\x12\x9c\x01\n\x0bListParents\x12 .eolymp.content.ListParentsInput\x1a!.eolymp.content.ListParentsOutput\"H\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xe3\n\x1c\x8a\xe3\n\x18typewriter:fragment:read\x82\xd3\xe4\x93\x02\x12\x12\x10/content/parents\x1a\x35\x82\xf0\xf0\xe4\x01\x15\x65olymp.universe.Space\x82\xf0\xf0\xe4\x01\x14\x65olymp.judge.ContestB1Z/github.com/eolymp/go-sdk/eolymp/content;contentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.content.content_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/content;content'
  _globals['_CONTENTSERVICE']._loaded_options = None
  _globals['_CONTENTSERVICE']._serialized_options = b'\202\360\360\344\001\025eolymp.universe.Space\202\360\360\344\001\024eolymp.judge.Contest'
  _globals['_CONTENTSERVICE'].methods_by_name['DescribeFragment']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['DescribeFragment']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\343\n\034\212\343\n\030typewriter:fragment:read\202\323\344\223\002\"\022 /content/fragments/{fragment_id}'
  _globals['_CONTENTSERVICE'].methods_by_name['ListFragments']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['ListFragments']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\034\212\343\n\030typewriter:fragment:read\202\323\344\223\002\024\022\022/content/fragments'
  _globals['_CONTENTSERVICE'].methods_by_name['CreateFragment']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['CreateFragment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\035\212\343\n\031typewriter:fragment:write\202\323\344\223\002\024\"\022/content/fragments'
  _globals['_CONTENTSERVICE'].methods_by_name['UpdateFragment']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['UpdateFragment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\035\212\343\n\031typewriter:fragment:write\202\323\344\223\002\"\032 /content/fragments/{fragment_id}'
  _globals['_CONTENTSERVICE'].methods_by_name['DeleteFragment']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['DeleteFragment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\035\212\343\n\031typewriter:fragment:write\202\323\344\223\002\"* /content/fragments/{fragment_id}'
  _globals['_CONTENTSERVICE'].methods_by_name['TranslateFragment']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['TranslateFragment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\035\212\343\n\031typewriter:fragment:write\202\323\344\223\002,\"*/content/fragments/{fragment_id}/translate'
  _globals['_CONTENTSERVICE'].methods_by_name['DescribeFragmentTranslation']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['DescribeFragmentTranslation']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\343\n\034\212\343\n\030typewriter:fragment:read\202\323\344\223\002~\022>/content/fragments/{fragment_id}/translations/{translation_id}Z<\022:/content/fragments/{fragment_id}/variants/{translation_id}'
  _globals['_CONTENTSERVICE'].methods_by_name['ListFragmentTranslations']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['ListFragmentTranslations']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\034\212\343\n\030typewriter:fragment:read\202\323\344\223\002\\\022-/content/fragments/{fragment_id}/translationsZ+\022)/content/fragments/{fragment_id}/variants'
  _globals['_CONTENTSERVICE'].methods_by_name['CreateFragmentTranslation']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['CreateFragmentTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\035\212\343\n\031typewriter:fragment:write\202\323\344\223\002\\\"-/content/fragments/{fragment_id}/translationsZ+\")/content/fragments/{fragment_id}/variants'
  _globals['_CONTENTSERVICE'].methods_by_name['UpdateFragmentTranslation']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['UpdateFragmentTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\035\212\343\n\031typewriter:fragment:write\202\323\344\223\002~\032>/content/fragments/{fragment_id}/translations/{translation_id}Z<\032:/content/fragments/{fragment_id}/variants/{translation_id}'
  _globals['_CONTENTSERVICE'].methods_by_name['DeleteFragmentTranslation']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['DeleteFragmentTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\035\212\343\n\031typewriter:fragment:write\202\323\344\223\002~*>/content/fragments/{fragment_id}/translations/{translation_id}Z<*:/content/fragments/{fragment_id}/variants/{translation_id}'
  _globals['_CONTENTSERVICE'].methods_by_name['DescribePath']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['DescribePath']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\343\n\034\212\343\n\030typewriter:fragment:read\202\323\344\223\002\017\022\r/content/path'
  _globals['_CONTENTSERVICE'].methods_by_name['ListParents']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['ListParents']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\343\n\034\212\343\n\030typewriter:fragment:read\202\323\344\223\002\022\022\020/content/parents'
  _globals['_FRAGMENTCHANGEDEVENT']._serialized_start=299
  _globals['_FRAGMENTCHANGEDEVENT']._serialized_end=419
  _globals['_FRAGMENTTRANSLATIONCHANGEDEVENT']._serialized_start=422
  _globals['_FRAGMENTTRANSLATIONCHANGEDEVENT']._serialized_end=583
  _globals['_DESCRIBEFRAGMENTINPUT']._serialized_start=585
  _globals['_DESCRIBEFRAGMENTINPUT']._serialized_end=683
  _globals['_DESCRIBEFRAGMENTOUTPUT']._serialized_start=685
  _globals['_DESCRIBEFRAGMENTOUTPUT']._serialized_end=753
  _globals['_LISTFRAGMENTSINPUT']._serialized_start=756
  _globals['_LISTFRAGMENTSINPUT']._serialized_end=1302
  _globals['_LISTFRAGMENTSINPUT_FILTER']._serialized_start=1039
  _globals['_LISTFRAGMENTSINPUT_FILTER']._serialized_end=1255
  _globals['_LISTFRAGMENTSINPUT_SORT']._serialized_start=1257
  _globals['_LISTFRAGMENTSINPUT_SORT']._serialized_end=1302
  _globals['_LISTFRAGMENTSOUTPUT']._serialized_start=1304
  _globals['_LISTFRAGMENTSOUTPUT']._serialized_end=1381
  _globals['_CREATEFRAGMENTINPUT']._serialized_start=1383
  _globals['_CREATEFRAGMENTINPUT']._serialized_end=1448
  _globals['_CREATEFRAGMENTOUTPUT']._serialized_start=1450
  _globals['_CREATEFRAGMENTOUTPUT']._serialized_end=1493
  _globals['_UPDATEFRAGMENTINPUT']._serialized_start=1496
  _globals['_UPDATEFRAGMENTINPUT']._serialized_end=1635
  _globals['_UPDATEFRAGMENTOUTPUT']._serialized_start=1637
  _globals['_UPDATEFRAGMENTOUTPUT']._serialized_end=1659
  _globals['_DELETEFRAGMENTINPUT']._serialized_start=1661
  _globals['_DELETEFRAGMENTINPUT']._serialized_end=1703
  _globals['_DELETEFRAGMENTOUTPUT']._serialized_start=1705
  _globals['_DELETEFRAGMENTOUTPUT']._serialized_end=1727
  _globals['_TRANSLATEFRAGMENTINPUT']._serialized_start=1730
  _globals['_TRANSLATEFRAGMENTINPUT']._serialized_end=1858
  _globals['_TRANSLATEFRAGMENTOUTPUT']._serialized_start=1860
  _globals['_TRANSLATEFRAGMENTOUTPUT']._serialized_end=1901
  _globals['_DESCRIBEFRAGMENTTRANSLATIONINPUT']._serialized_start=1904
  _globals['_DESCRIBEFRAGMENTTRANSLATIONINPUT']._serialized_end=2037
  _globals['_DESCRIBEFRAGMENTTRANSLATIONOUTPUT']._serialized_start=2039
  _globals['_DESCRIBEFRAGMENTTRANSLATIONOUTPUT']._serialized_end=2133
  _globals['_LISTFRAGMENTTRANSLATIONSINPUT']._serialized_start=2136
  _globals['_LISTFRAGMENTTRANSLATIONSINPUT']._serialized_end=2462
  _globals['_LISTFRAGMENTTRANSLATIONSINPUT_FILTER']._serialized_start=2345
  _globals['_LISTFRAGMENTTRANSLATIONSINPUT_FILTER']._serialized_end=2462
  _globals['_LISTFRAGMENTTRANSLATIONSOUTPUT']._serialized_start=2464
  _globals['_LISTFRAGMENTTRANSLATIONSOUTPUT']._serialized_end=2564
  _globals['_CREATEFRAGMENTTRANSLATIONINPUT']._serialized_start=2566
  _globals['_CREATEFRAGMENTTRANSLATIONINPUT']._serialized_end=2678
  _globals['_CREATEFRAGMENTTRANSLATIONOUTPUT']._serialized_start=2680
  _globals['_CREATEFRAGMENTTRANSLATIONOUTPUT']._serialized_end=2737
  _globals['_UPDATEFRAGMENTTRANSLATIONINPUT']._serialized_start=2740
  _globals['_UPDATEFRAGMENTTRANSLATIONINPUT']._serialized_end=2876
  _globals['_UPDATEFRAGMENTTRANSLATIONOUTPUT']._serialized_start=2878
  _globals['_UPDATEFRAGMENTTRANSLATIONOUTPUT']._serialized_end=2911
  _globals['_DELETEFRAGMENTTRANSLATIONINPUT']._serialized_start=2913
  _globals['_DELETEFRAGMENTTRANSLATIONINPUT']._serialized_end=2990
  _globals['_DELETEFRAGMENTTRANSLATIONOUTPUT']._serialized_start=2992
  _globals['_DELETEFRAGMENTTRANSLATIONOUTPUT']._serialized_end=3025
  _globals['_DESCRIBEPATHINPUT']._serialized_start=3027
  _globals['_DESCRIBEPATHINPUT']._serialized_end=3130
  _globals['_DESCRIBEPATHOUTPUT']._serialized_start=3132
  _globals['_DESCRIBEPATHOUTPUT']._serialized_end=3196
  _globals['_LISTPARENTSINPUT']._serialized_start=3198
  _globals['_LISTPARENTSINPUT']._serialized_end=3300
  _globals['_LISTPARENTSOUTPUT']._serialized_start=3302
  _globals['_LISTPARENTSOUTPUT']._serialized_end=3377
  _globals['_CONTENTSERVICE']._serialized_start=3380
  _globals['_CONTENTSERVICE']._serialized_end=6350
# @@protoc_insertion_point(module_scope)
