# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/discussion/thread_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/discussion/thread_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import namespace_pb2 as eolymp_dot_annotations_dot_namespace__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.discussion import message_service_pb2 as eolymp_dot_discussion_dot_message__service__pb2
from eolymp.discussion import subscription_service_pb2 as eolymp_dot_discussion_dot_subscription__service__pb2
from eolymp.discussion import thread_pb2 as eolymp_dot_discussion_dot_thread__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/discussion/thread_service.proto\x12\x11\x65olymp.discussion\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/namespace.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\'eolymp/discussion/message_service.proto\x1a,eolymp/discussion/subscription_service.proto\x1a\x1e\x65olymp/discussion/thread.proto\"%\n\x13\x44\x65scribeThreadInput\x12\x0e\n\x06locale\x18\n \x01(\t\"A\n\x14\x44\x65scribeThreadOutput\x12)\n\x06thread\x18\x01 \x01(\x0b\x32\x19.eolymp.discussion.Thread\"3\n\x0fVoteThreadInput\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12\x0c\n\x04vote\x18\x02 \x01(\x05\"&\n\x10VoteThreadOutput\x12\x12\n\nvote_count\x18\x01 \x01(\x05\x32\xe9\r\n\rThreadService\x12\x81\x01\n\x0e\x44\x65scribeThread\x12&.eolymp.discussion.DescribeThreadInput\x1a\'.eolymp.discussion.DescribeThreadOutput\"\x1e\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\t\x12\x07/thread\x12z\n\nVoteThread\x12\".eolymp.discussion.VoteThreadInput\x1a#.eolymp.discussion.VoteThreadOutput\"#\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x0e\"\x0c/thread/vote\x12\xbf\x01\n\x12UpdateSubscription\x12*.eolymp.discussion.UpdateSubscriptionInput\x1a+.eolymp.discussion.UpdateSubscriptionOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n!\x8a\xe3\n\x1d\x64iscussion:subscription:write\x82\xd3\xe4\x93\x02\x16\x1a\x14/thread/subscription\x12\xba\x01\n\x0f\x44\x65scribeMessage\x12\'.eolymp.discussion.DescribeMessageInput\x1a(.eolymp.discussion.DescribeMessageOutput\"T\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xe3\n\x1b\x8a\xe3\n\x17\x64iscussion:message:read\x82\xd3\xe4\x93\x02\x1f\x12\x1d/thread/messages/{message_id}\x12\xa3\x01\n\x0cListMessages\x12$.eolymp.discussion.ListMessagesInput\x1a%.eolymp.discussion.ListMessagesOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x1b\x8a\xe3\n\x17\x64iscussion:message:read\x82\xd3\xe4\x93\x02\x12\x12\x10/thread/messages\x12\xa1\x01\n\x0bPostMessage\x12#.eolymp.discussion.PostMessageInput\x1a$.eolymp.discussion.PostMessageOutput\"G\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x02\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\x82\xd3\xe4\x93\x02\x12\"\x10/thread/messages\x12\xb4\x01\n\rUpdateMessage\x12%.eolymp.discussion.UpdateMessageInput\x1a&.eolymp.discussion.UpdateMessageOutput\"T\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x02\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\x82\xd3\xe4\x93\x02\x1f\x1a\x1d/thread/messages/{message_id}\x12\xad\x01\n\rDeleteMessage\x12%.eolymp.discussion.DeleteMessageInput\x1a&.eolymp.discussion.DeleteMessageOutput\"M\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\x82\xd3\xe4\x93\x02\x18*\x16/messages/{message_id}\x12\xac\x01\n\x0bVoteMessage\x12#.eolymp.discussion.VoteMessageInput\x1a$.eolymp.discussion.VoteMessageOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x02\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\x82\xd3\xe4\x93\x02\x1d\"\x1b/messages/{message_id}/vote\x12\xc3\x01\n\x12ListMessageChanges\x12*.eolymp.discussion.ListMessageChangesInput\x1a+.eolymp.discussion.ListMessageChangesOutput\"T\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x1b\x8a\xe3\n\x17\x64iscussion:message:read\x82\xd3\xe4\x93\x02 \x12\x1e/messages/{message_id}/changes\x1a\x33\x82\xf0\xf0\xe4\x01\x14\x65olymp.atlas.Problem\x82\xf0\xf0\xe4\x01\x13\x65olymp.content.PostB7Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.thread_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _globals['_THREADSERVICE']._loaded_options = None
  _globals['_THREADSERVICE']._serialized_options = b'\202\360\360\344\001\024eolymp.atlas.Problem\202\360\360\344\001\023eolymp.content.Post'
  _globals['_THREADSERVICE'].methods_by_name['DescribeThread']._loaded_options = None
  _globals['_THREADSERVICE'].methods_by_name['DescribeThread']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\t\022\007/thread'
  _globals['_THREADSERVICE'].methods_by_name['VoteThread']._loaded_options = None
  _globals['_THREADSERVICE'].methods_by_name['VoteThread']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\016\"\014/thread/vote'
  _globals['_THREADSERVICE'].methods_by_name['UpdateSubscription']._loaded_options = None
  _globals['_THREADSERVICE'].methods_by_name['UpdateSubscription']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n!\212\343\n\035discussion:subscription:write\202\323\344\223\002\026\032\024/thread/subscription'
  _globals['_THREADSERVICE'].methods_by_name['DescribeMessage']._loaded_options = None
  _globals['_THREADSERVICE'].methods_by_name['DescribeMessage']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\343\n\033\212\343\n\027discussion:message:read\202\323\344\223\002\037\022\035/thread/messages/{message_id}'
  _globals['_THREADSERVICE'].methods_by_name['ListMessages']._loaded_options = None
  _globals['_THREADSERVICE'].methods_by_name['ListMessages']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\033\212\343\n\027discussion:message:read\202\323\344\223\002\022\022\020/thread/messages'
  _globals['_THREADSERVICE'].methods_by_name['PostMessage']._loaded_options = None
  _globals['_THREADSERVICE'].methods_by_name['PostMessage']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\002\202\343\n\034\212\343\n\030discussion:message:write\202\323\344\223\002\022\"\020/thread/messages'
  _globals['_THREADSERVICE'].methods_by_name['UpdateMessage']._loaded_options = None
  _globals['_THREADSERVICE'].methods_by_name['UpdateMessage']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\002\202\343\n\034\212\343\n\030discussion:message:write\202\323\344\223\002\037\032\035/thread/messages/{message_id}'
  _globals['_THREADSERVICE'].methods_by_name['DeleteMessage']._loaded_options = None
  _globals['_THREADSERVICE'].methods_by_name['DeleteMessage']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\034\212\343\n\030discussion:message:write\202\323\344\223\002\030*\026/messages/{message_id}'
  _globals['_THREADSERVICE'].methods_by_name['VoteMessage']._loaded_options = None
  _globals['_THREADSERVICE'].methods_by_name['VoteMessage']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\002\202\343\n\034\212\343\n\030discussion:message:write\202\323\344\223\002\035\"\033/messages/{message_id}/vote'
  _globals['_THREADSERVICE'].methods_by_name['ListMessageChanges']._loaded_options = None
  _globals['_THREADSERVICE'].methods_by_name['ListMessageChanges']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\033\212\343\n\027discussion:message:read\202\323\344\223\002 \022\036/messages/{message_id}/changes'
  _globals['_DESCRIBETHREADINPUT']._serialized_start=315
  _globals['_DESCRIBETHREADINPUT']._serialized_end=352
  _globals['_DESCRIBETHREADOUTPUT']._serialized_start=354
  _globals['_DESCRIBETHREADOUTPUT']._serialized_end=419
  _globals['_VOTETHREADINPUT']._serialized_start=421
  _globals['_VOTETHREADINPUT']._serialized_end=472
  _globals['_VOTETHREADOUTPUT']._serialized_start=474
  _globals['_VOTETHREADOUTPUT']._serialized_end=512
  _globals['_THREADSERVICE']._serialized_start=515
  _globals['_THREADSERVICE']._serialized_end=2284
# @@protoc_insertion_point(module_scope)
